powered by
Forecast
This S4 class represents the result of forecast using function predictValue.
predictValue
data
(data.frame) Data frame including the predicted data and optionally the training data.
models
(list) List of fitted ARIMA models.
value
(character) Name of the value column.
item
(character) Name of the item column.
items
(character) IDs or Names of the items.
Objects can be created by calling the function predictValue. This S4 class represents the result of a forecast.
Leon Binder [email protected]
Bernhard Bauer [email protected]
Michael Scholz [email protected]
data("Amount") prediction = predictValue(data = Amount, value = "amount", item = "item", timestamp = "date", temporalAggregation = "week", timeUnitsAhead = 3) prediction
Run the code above in your browser using DataLab